"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Streamdal = exports.SDKResponse = exports.OperationType = exports.ExecStatus = exports.Audience = void 0;
const sp_common_1 = require("@streamdal/protos/protos/sp_common");
Object.defineProperty(exports, "Audience", { enumerable: true, get: function () { return sp_common_1.Audience; } });
Object.defineProperty(exports, "OperationType", { enumerable: true, get: function () { return sp_common_1.OperationType; } });
const sp_sdk_1 = require("@streamdal/protos/protos/sp_sdk");
Object.defineProperty(exports, "ExecStatus", { enumerable: true, get: function () { return sp_sdk_1.ExecStatus; } });
Object.defineProperty(exports, "SDKResponse", { enumerable: true, get: function () { return sp_sdk_1.SDKResponse; } });
const uuid_1 = require("uuid");
const audience_js_1 = require("./internal/audience.js");
const grpc_js_1 = require("./internal/grpc.js");
const heartbeat_js_1 = require("./internal/heartbeat.js");
const metrics_js_1 = require("./internal/metrics.js");
const process_js_1 = require("./internal/process.js");
const register_js_1 = require("./internal/register.js");
class Streamdal {
    configs;
    constructor({ streamdalUrl, streamdalToken, serviceName, pipelineTimeout, stepTimeout, dryRun, audiences, quiet, }) {
        if (quiet || process.env.NODE_ENV === "production") {
            console.debug = () => null;
        }
        const url = streamdalUrl ? streamdalUrl : process.env.STREAMDAL_URL;
        const token = streamdalToken ? streamdalToken : process.env.STREAMDAL_TOKEN;
        const name = serviceName ? serviceName : process.env.STREAMDAL_SERVICE_NAME;
        if (!url || !token || !name) {
            throw new Error(`Required configs are missing. You must provide configs streamdalUrl, streamdalToken and serviceName 
        either as constructor arguments to Streamdal() or as environment variables in the form of STREAMDAL_URL, STREAMDAL_TOKEN and STREAMDAL_SERVICE_NAME`);
        }
        const sessionId = (0, uuid_1.v4)();
        const grpcClient = (0, grpc_js_1.client)(url);
        this.configs = {
            grpcClient,
            sessionId,
            streamdalUrl: url,
            streamdalToken: token,
            serviceName: name,
            pipelineTimeout: pipelineTimeout ?? process.env.STREAMDAL_PIPELINE_TIMEOUT ?? "100",
            stepTimeout: stepTimeout ?? process.env.STREAMDAL_STEP_TIMEOUT ?? "10",
            dryRun: dryRun ?? !!process.env.STREAMDAL_DRY_RUN,
            audiences,
        };
        // Heartbeat is obsolete
        setInterval(() => {
            void (0, heartbeat_js_1.heartbeat)(this.configs);
        }, heartbeat_js_1.HEARTBEAT_INTERVAL);
        setInterval(() => {
            (0, metrics_js_1.sendMetrics)(this.configs);
        }, metrics_js_1.METRIC_INTERVAL);
        void (0, audience_js_1.addAudiences)(this.configs);
        void (0, register_js_1.register)(this.configs);
    }
    async process({ audience, data }) {
        return (0, process_js_1.retryProcessPipelines)({ configs: this.configs, audience, data });
    }
}
exports.Streamdal = Streamdal;
//# sourceMappingURL=streamdal.js.map